@@ -2,7 +2,7 @@
    Project: LaternaMagica
    AppController.m
 
-   Copyright (C) 2006-2009 Riccardo Mottola
+   Copyright (C) 2006-2010 Riccardo Mottola
 
    Author: Riccardo Mottola
 
@@ -24,6 +24,7 @@
 */
 
 #import "AppController.h"
+#import "PRScale.h"
 
 
 @implementation AppController
@@ -96,6 +97,7 @@
     openPanel = [NSOpenPanel openPanel];
     [openPanel setAllowsMultipleSelection:YES];
     [openPanel setCanChooseDirectories:YES];
+    [openPanel setCanChooseFiles:YES];
     if ([openPanel runModalForTypes:NULL] != NSOKButton)
     {
         return;
@@ -132,6 +134,8 @@
                         {
                             if (!([lastPathComponent isEqualToString:@".gwdir"] || [lastPathComponent isEqualToString:@".DS_Store"]))
                             {
+			      /* hide dot files, eventually a preference could be implemented */
+			      if (![lastPathComponent hasPrefix: @"."])
                                 [self addFile:tempName];
                             }
                         }
@@ -146,6 +150,7 @@
             NSLog(@"open panel did not return a valid path");
         }
     }
+  [fileListView selectRow: [fileListView numberOfRows]-1 byExtendingSelection: NO];
 }
 
 // scale image according to options
@@ -154,6 +159,9 @@
     NSPoint rectOrigin;
     NSSize rectSize;
 
+    if (image == nil)
+      return;
+      
     rectSize =  [window frame].size;
     if (scaleToFit)
     {
@@ -369,6 +377,7 @@
         }
 }
 
+
 - (IBAction)rotateImage90:(id)sender
 {
     NSImage *srcImage;
@@ -562,7 +571,7 @@
 {
     NSImage *srcImage;
     NSBitmapImageRep *srcImageRep;
-    NSData *dataOfRep;
+    NSData *dataOfRep = nil;
     NSDictionary *repProperties;
     NSString *origFileName;
     NSString *filenameNoExtension;
@@ -605,15 +614,15 @@
         }
         [dataOfRep writeToFile:fileName atomically:NO];            
     }
-//    [savePanel release];
 }
 
 
 /* ===== delegates =====*/
 - (BOOL)application:(NSApplication *)theApplication openFile:(NSString *)filename
 {
-    [self addFile:filename];
-    return YES;
+  [self addFile:filename];
+  [fileListView selectRow: [fileListView numberOfRows]-1 byExtendingSelection: NO];
+  return YES;
 }
 
 /* save panel delegates */
@@ -655,5 +664,174 @@
         [jpegCompressionField takeFloatValueFrom:sender];
 }
 
+/* exporter */
+- (IBAction)exportImages:(id)sender
+{
+  [exporterPanel makeKeyAndOrderFront:self];
+  [exportProgress setDoubleValue: 0.0];
+}
+
+- (IBAction)setExportPath:(id)sender
+{
+  NSOpenPanel *openPanel;
+  NSString    *choosenFilePath;
+  
+  openPanel = [NSOpenPanel openPanel];
+  [openPanel setAllowsMultipleSelection:NO];
+  [openPanel setCanChooseDirectories:YES];
+  [openPanel setCanChooseFiles:NO];
+  if ([openPanel runModalForTypes:NULL] != NSOKButton)
+    {
+      return;
+    }
+  
+  choosenFilePath = [openPanel filename];
+  [fieldOutputPath setStringValue:choosenFilePath];
+}
+
+- (IBAction)execExportImages:(id)sender
+{
+  int givenHeight;
+  int givenWidth;
+  NSDictionary *repProperties;
+  NSString *origFileName;
+  NSString *filenameNoExtension;
+  NSImage *srcImage;
+  NSBitmapImageRep *srcImageRep;
+  NSData *dataOfRep;
+  NSString *destFileName;
+  NSString *destFileExtension;
+  NSString *destFolder;
+  int i;
+  
+  givenHeight = [fieldHeight intValue];
+  givenWidth = [fieldWidth intValue];
+
+  destFolder = [fieldOutputPath stringValue];
+  
+  if ([popupFileType indexOfSelectedItem] == 0)
+    destFileExtension = @"tiff";
+  else
+    destFileExtension = @"jpeg";
+
+  [exportProgress setDoubleValue: 0.0];
+  [exporterPanel displayIfNeeded];
+  for (i = 0; i < [fileListView numberOfRows]; i++)
+    {
+      NSString *fullOrigPath;
+      int newW, newH;
+      double aspectRatio;
+      NSBitmapImageRep *scaledImageRep;
+      NSAutoreleasePool *pool;
+
+      /* create a local pool to avoid the autorelease to grow too much */
+      pool = [[NSAutoreleasePool alloc] init];
+      fullOrigPath = [fileListData pathAtIndex:i];
+      origFileName = [fullOrigPath lastPathComponent];
+      filenameNoExtension = [origFileName stringByDeletingPathExtension];
+      
+
+      srcImage = [[NSImage alloc] initByReferencingFile:fullOrigPath];
+      srcImageRep = [NSBitmapImageRep imageRepWithData:[srcImage TIFFRepresentation]];
+
+      newW = [srcImageRep size].width;
+      newH = [srcImageRep size].height;
+      aspectRatio = (double)newW / newH;
+      NSLog(@"aspect ratio: %f", aspectRatio);
+      switch([popupConstraints indexOfSelectedItem])
+	{
+	case 0: /* none */
+	  break;
+	case 1: /* width */
+	  newW = givenWidth;
+	  newH = givenWidth / aspectRatio;
+	  break;
+	case 2: /* height */
+	  newH = givenHeight;
+	  newW = givenHeight * aspectRatio;
+	  break;
+	case 3: /* both */
+	  newW = givenWidth;
+	  newH = givenWidth / aspectRatio;
+          if (newH > givenHeight)
+            {
+              newH = givenHeight;
+              newW = givenHeight * aspectRatio;
+            }
+	  break;
+	case 4: /* largest side */
+	  if ([srcImageRep size].height > [srcImageRep size].width)
+	    {
+	      newH = givenWidth;
+	      newW = givenWidth * aspectRatio;
+	    }
+	  else
+	    {
+	      newW = givenWidth;
+	      newH = givenWidth / aspectRatio;
+	    }
+	  break;
+	default:
+	  NSLog(@"Unexpected constraint selection value.");
+	}
+      NSLog(@"%d %d", newW, newH);
+      if (newW == [srcImageRep size].width)
+	{
+	  NSLog(@"nothing");
+	  scaledImageRep = srcImageRep;
+	}
+      else
+	{
+	  NSImage *scaledImage;
+	  PRScale *scaleFilter;
+	  
+	  scaleFilter = [[PRScale alloc] init];
+	  scaledImage = [scaleFilter scaleImage:srcImage :newW :newH :LINEAR_HV :nil];
+	  [scaleFilter release];
+	  scaledImageRep = [NSBitmapImageRep imageRepWithData:[scaledImage TIFFRepresentation]];
+	}
+
+      if ([popupFileType indexOfSelectedItem] == 0)
+        {
+          repProperties = [NSDictionary dictionaryWithObject:[NSNumber numberWithInt:NSTIFFCompressionLZW] forKey:NSImageCompressionMethod];
+          dataOfRep = [scaledImageRep representationUsingType: NSTIFFFileType properties:repProperties];
+        }
+      else
+        {
+          float quality;
+	  
+	  switch ([popupFileQuality indexOfSelectedItem])
+	    {
+	    case 0:
+	      quality = 1.0;
+	      break;
+	    case 1:
+	      quality = 0.75;
+	      break;
+	    case 2:
+	      quality = 0.66;
+	      break;
+	    case 3:
+	      quality = 0.4;
+	      break;
+	    default:
+	      quality = 0.5;
+            }
+          repProperties = [NSDictionary dictionaryWithObject:[NSNumber numberWithFloat:quality] forKey:NSImageCompressionFactor];
+          dataOfRep = [scaledImageRep representationUsingType: NSJPEGFileType properties:repProperties];
+        }
+      [srcImage release];
+
+      destFileName = [destFolder stringByAppendingPathComponent:[filenameNoExtension stringByAppendingPathExtension: destFileExtension]];
+      NSLog(@"%@", destFileName);
+      if (dataOfRep != nil)
+        {
+          [dataOfRep writeToFile:destFileName atomically:NO];
+        }
+      [exportProgress setDoubleValue: ((double)(i+1)*100)/(double)[fileListView numberOfRows]];
+      [exporterPanel displayIfNeeded];
+      [pool release];
+    }
+}
 
 @end
